@@ -34,6 +34,14 @@ class SpiderBaseMiddleware:
         :return:
         """
 
+    def spider_end(self, spider: Spider) -> None:
+        """
+        spider 结束的操作（分布式时多个机器也只会执行一次）
+
+        :param spider:
+        :return:
+        """
+
 
 class SpiderMiddleware(SpiderBaseMiddleware):
     """
@@ -64,3 +72,11 @@ class SpiderMiddleware(SpiderBaseMiddleware):
         :param spider:
         :return:
         """
+
+    def spider_end(self, spider) -> None:
+        """
+        spider 结束的操作（分布式时多个机器也只会执行一次）
+
+        :param spider:
+        :return:
+        """
